pub(crate) struct ScriptClass {
pub name: &'static str,
pub group: ScriptGroup,
pub tag: Tag,
pub hint_top_to_bottom: bool,
pub std_chars: &'static str,
pub blues: &'static [(&'static str, BlueZones)],
}Expand description
Defines the basic properties for each script supported by the autohinter.
Fields
name: &'static strgroup: ScriptGroupGroup that defines how glyphs belonging to this script are hinted.
tag: TagUnicode tag for the script.
hint_top_to_bottom: boolTrue if outline edges are processed top to bottom.
std_chars: &'static strCharacters used to define standard width and height of stems.
blues: &'static [(&'static str, BlueZones)]“Blue” characters used to define alignment zones.
Implementations
Sourceimpl ScriptClass
impl ScriptClass
pub const ADLM: usize = 0
pub const ARAB: usize = 1
pub const ARMN: usize = 2
pub const AVST: usize = 3
pub const BAMU: usize = 4
pub const BENG: usize = 5
pub const BUHD: usize = 6
pub const CAKM: usize = 7
pub const CANS: usize = 8
pub const CARI: usize = 9
pub const CHER: usize = 10
pub const COPT: usize = 11
pub const CPRT: usize = 12
pub const CYRL: usize = 13
pub const DEVA: usize = 14
pub const DSRT: usize = 15
pub const ETHI: usize = 16
pub const GEOR: usize = 17
pub const GEOK: usize = 18
pub const GLAG: usize = 19
pub const GOTH: usize = 20
pub const GREK: usize = 21
pub const GUJR: usize = 22
pub const GURU: usize = 23
pub const HEBR: usize = 24
pub const KALI: usize = 25
pub const KHMR: usize = 26
pub const KHMS: usize = 27
pub const KNDA: usize = 28
pub const LAOO: usize = 29
pub const LATN: usize = 30
pub const LATB: usize = 31
pub const LATP: usize = 32
pub const LISU: usize = 33
pub const MLYM: usize = 34
pub const MEDF: usize = 35
pub const MONG: usize = 36
pub const MYMR: usize = 37
pub const NKOO: usize = 38
pub const NONE: usize = 39
pub const OLCK: usize = 40
pub const ORKH: usize = 41
pub const OSGE: usize = 42
pub const OSMA: usize = 43
pub const ROHG: usize = 44
pub const SAUR: usize = 45
pub const SHAW: usize = 46
pub const SINH: usize = 47
pub const SUND: usize = 48
pub const TAML: usize = 49
pub const TAVT: usize = 50
pub const TELU: usize = 51
pub const TFNG: usize = 52
pub const THAI: usize = 53
pub const VAII: usize = 54
pub const LIMB: usize = 55
pub const ORYA: usize = 56
pub const SYLO: usize = 57
pub const TIBT: usize = 58
pub const HANI: usize = 59